Only in filter-dnsbl: .git
Only in filter-dnsbl: README.md
diff -aur filter-dnsbl.orig/filter-dnsbl.8 filter-dnsbl/filter-dnsbl.8
--- filter-dnsbl.orig/filter-dnsbl.8	Tue Dec  7 15:37:18 2021
+++ filter-dnsbl/filter-dnsbl.8	Wed Apr  6 16:32:01 2022
@@ -22,7 +22,7 @@
 .Nd block senders based on dnsbl
 .Sh SYNOPSIS
 .Nm
-.Op Fl mv
+.Op Fl mpv
 .Ar blacklist
 .Ar ...
 .Sh DESCRIPTION
@@ -38,5 +38,10 @@
 For more verbose logging the
 .Fl v
 flag can be used.
+If the
+.Fl p
+flag is specified, the message will be permanently rejected with a 550 error
+code.
+.Pp
 .Sh SEE ALSO
 .Xr smtpd 8
diff -aur filter-dnsbl.orig/main.c filter-dnsbl/main.c
--- filter-dnsbl.orig/main.c	Wed Apr  6 16:31:11 2022
+++ filter-dnsbl/main.c	Wed Apr  6 16:32:38 2022
@@ -52,6 +52,7 @@
 static const char **printblacklists;
 static size_t nblacklists = 0;
 static int markspam = 0;
+static int permanent = 0;
 static int verbose = 0;
 
 const char *dnsbl_printblacklist(const char *);
@@ -71,11 +72,14 @@
 	int ch;
 	size_t i;
 
-	while ((ch = getopt(argc, argv, "mv")) != -1) {
+	while ((ch = getopt(argc, argv, "mpv")) != -1) {
 		switch (ch) {
 		case 'm':
 			markspam = 1;
 			break;
+		case 'p':
+			permanent = 550;
+			break;
 		case 'v':
 			verbose = 1;
 			break;
@@ -190,8 +194,13 @@
 	query->event = NULL;
 	if (result->ar_hostent != NULL) {
 		if (!markspam) {
-			osmtpd_filter_disconnect(session->ctx, "Listed at %s",
+			if (permanent) {
+			    osmtpd_filter_reject(session->ctx, permanent, "Listed at %s",
 			    printblacklists[query->blacklist]);
+			} else {
+			   osmtpd_filter_disconnect(session->ctx, "Listed at %s",
+			   printblacklists[query->blacklist]);
+                       }
 			fprintf(stderr, "%016"PRIx64" listed at %s: rejected\n",
 			    session->ctx->reqid,
 			    printblacklists[query->blacklist]);
Only in filter-dnsbl: main.c.orig
Only in filter-dnsbl: main.d
